@@ -20,6 +20,8 @@
 
 namespace LibreNMS;
 
+use LibreNMS\Exceptions\DatabaseConnectException;
+
 class IRCBot
 {
 
@@ -161,6 +163,10 @@ class IRCBot
                 }
             }
 
+            if (isset($this->tempnick)) {
+                 $this->ircRaw('NICK '.$this->nick);
+            }
+
             $this->getData();
             if ($this->config['irc_alert']) {
                 $this->alertData();
@@ -244,26 +250,31 @@ class IRCBot
                     $severity_extended = '';
             endswitch;
 
-            $severity = str_replace(array('warning', 'critical'), array(chr(3).'8Warning', chr(3).'4Critical'), $alert['severity']).$severity_extended.chr(3).' ';
+            $severity = str_replace(array('warning', 'critical'), array($this->_color('Warning', 'yellow'), $this->_color('Critical', 'red')), $alert['severity']).$severity_extended.' ';
             if ($alert['state'] == 0 and $this->config['irc_alert_utf8']) {
-                $severity = str_replace(array('Warning', 'Critical'), array('W̶a̶r̶n̶i̶n̶g̶', 'C̶r̶i̶t̶i̶c̶a̶l̶'), $severity);
+                $severity = str_replace(array('Warning', 'Critical'), array('̶W̶a̶r̶n̶i̶n̶g', '̶C̶r̶i̶t̶i̶c̶a̶l'), $severity);
             }
 
             if ($this->config['irc_alert_chan']) {
                 foreach ($this->config['irc_alert_chan'] as $chan) {
-                    $this->ircRaw('PRIVMSG '.$chan.' :'.$severity.trim($alert['title']).' - Rule: '.trim($alert['name'] ? $alert['name'] : $alert['rule']).(sizeof($alert['faults']) > 0 ? ' - Faults:' : ''));
-                    foreach ($alert['faults'] as $k => $v) {
-                        $this->ircRaw('PRIVMSG '.$chan.' :#'.$k.' '.$v['string']);
+                    $this->ircRaw('PRIVMSG '.$chan.' :'.$severity.trim($alert['title']));
+                    foreach (explode("\n", $alert['msg']) as $line) {
+                        // We don't need to repeat the title
+                        $line = strip_tags($line);
+                        if (trim($line) != trim($alert['title'])) {
+                            $this->ircRaw('PRIVMSG '.$chan.' :'.$line);
+                        }
                     }
                 }
             } else {
                 foreach ($this->authd as $nick => $data) {
                     if ($data['expire'] >= time()) {
-                        $this->ircRaw('PRIVMSG '.$nick.' :'.$severity.trim($alert['title']).' - Rule: '.trim($alert['name'] ? $alert['name'] : $alert['rule']).(sizeof($alert['faults']) > 0 ? ' - Faults'.(sizeof($alert['faults']) > 3 ? ' (showing first 3 out of '.sizeof($alert['faults']).' )' : '' ).':' : ''));
-                        foreach ($alert['faults'] as $k => $v) {
-                            $this->ircRaw('PRIVMSG '.$nick.' :#'.$k.' '.$v['string']);
-                            if ($k >= 3) {
-                                break;
+                        $this->ircRaw('PRIVMSG '.$nick.' :'.$severity.trim($alert['title']));
+                        foreach (explode("\n", $alert['msg']) as $line) {
+                            // We don't need to repeat the title
+                            $line = strip_tags($line);
+                            if (trim($line) != trim($alert['title'])) {
+                                $this->ircRaw('PRIVMSG '.$nick.' :'.$line);
                             }
                         }
                     }
@@ -290,6 +301,52 @@ class IRCBot
                 }
             }
 
+            if (($this->config['irc_ctcp']) && (preg_match("/^:".chr(1).".*/", $ex[3]))) {
+                // Handle CTCP
+                $ctcp = trim(preg_replace("/[^A-Z]/", "", $ex[3]));
+                $ctcp_reply = null;
+                $this->log("Received irc CTCP: ".$ctcp." from ".$this->getUser($this->data));
+                switch ($ctcp) {
+                    case 'VERSION':
+                        $ctcp_reply = chr(1)."$ctcp ".$this->config['irc_ctcp_version'].chr(1);
+                        break;
+                    case 'PING':
+                        $ctcp_reply = chr(1)."$ctcp ".$ex[4]. " ".$ex[5].chr(1);
+                        break;
+                    case 'TIME':
+                        $ctcp_reply = chr(1)."$ctcp ".date('c').chr(1);
+                        break;
+                }
+                if ($ctcp_reply !== null) {
+                    $this->log("Sending irc CTCP: ".'NOTICE '.$this->getUser($this->data)." :".$ctcp_reply);
+                    return $this->ircRaw('NOTICE '.$this->getUser($this->data)." :".$ctcp_reply);
+                }
+            }
+
+            if (($ex[1] == 'NICK') && (preg_replace("/^:/", "", $ex[2]) == $this->nick)) {
+                // Nickname changed successfully
+                if ($this->debug) {
+                    $this->log("Regained our real nick");
+                }
+                unset($this->tempnick);
+            }
+            if (($ex[1] == 433) || ($ex[1] == 437)) {
+                // Nickname already in use / temp unavailable
+                if ($this->debug) {
+                    $this->log("Nickname already in use...");
+                }
+                if ($ex[2] != "*") {
+                    $this->tempnick = $ex[2];
+                }
+                if (!isset($this->tempnick)) {
+                     $this->tempnick = $this->nick.rand(0, 99);
+                }
+                if ($this->debug) {
+                    $this->log("Using temp nick ".$this->tempnick);
+                }
+                return $this->ircRaw('NICK '.$this->tempnick);
+            }
+
             $this->command = str_replace(array(chr(10), chr(13)), '', $ex[3]);
             if (strstr($this->command, ':.')) {
                 $this->handleCommand();
@@ -317,6 +374,9 @@ class IRCBot
         $this->command = str_replace(':.', '', $this->command);
         $tmp           = explode(':.'.$this->command.' ', $this->data);
         $this->user    = $this->getAuthdUser();
+        if (!$this->isAuthd() && (isset($this->config['irc_auth']))) {
+            $this->hostAuth();
+        }
         if ($this->isAuthd() || trim($this->command) == 'auth') {
             $this->proceedCommand(str_replace("\n", '', trim($this->command)), trim($tmp[1]));
         }
@@ -364,8 +424,13 @@ class IRCBot
         return str_replace(':', '', $arrData[0]);
     }//end getUser()
 
+    private function getUserHost($param)
+    {
+        $arrData = explode(' ', $param, 2);
+        return str_replace(':', '', $arrData[0]);
+    }//end getUserHost()
 
-    private function connect($try)
+    private function connect($try = 0)
     {
         if ($try > $this->max_retry) {
             $this->log('Failed too many connection attempts, aborting');
@@ -374,6 +439,7 @@ class IRCBot
 
         $this->log('Trying to connect ('.($try + 1).') to '.$this->server.':'.$this->port.($this->ssl ? ' (SSL)' : ''));
         if ($this->socket['irc']) {
+            $this->ircRaw('QUIT :Reloading');
             fclose($this->socket['irc']);
         }
 
@@ -437,15 +503,21 @@ class IRCBot
     private function chkdb()
     {
         if (!is_resource($this->sql)) {
-            if (($this->sql = mysqli_connect($this->config['db_host'], $this->config['db_user'], $this->config['db_pass'], null, $this->config['db_port'])) != false && mysqli_select_db($this->sql, $this->config['db_name'])) {
-                return true;
-            } else {
-                $this->log('Cannot connect to MySQL');
+            try {
+                $this->sql = dbConnect(
+                    $this->config['db_host'],
+                    $this->config['db_user'],
+                    $this->config['db_pass'],
+                    $this->config['db_name'],
+                    $this->config['db_port'],
+                    $this->config['db_socket']
+                );
+            } catch (DatabaseConnectException $e) {
+                $this->log('Cannot connect to MySQL: ' . $e->getMessage());
                 return die();
             }
-        } else {
-            return true;
         }
+        return true;
     }//end chkdb()
 
 
@@ -463,7 +535,38 @@ class IRCBot
     private function getAuthdUser()
     {
         return $this->authd[$this->getUser($this->data)];
-    }//end get_user()
+    }//end getAuthUser()
+
+    private function hostAuth()
+    {
+        foreach ($this->config['irc_auth'] as $nms_user => $hosts) {
+            foreach ($hosts as $host) {
+                $host = preg_replace("/\*/", ".*", $host);
+                if (preg_match("/$host/", $this->getUserHost($this->data))) {
+                    $user_id = get_userid(mres($nms_user));
+                    $user = get_user($user_id);
+                    $this->user['name'] = $user['username'];
+                    $this->user['id']   = $user_id;
+                    $this->user['level'] = get_userlevel($user['username']);
+                    $this->user['expire'] = (time() + ($this->config['irc_authtime'] * 3600));
+                    if ($this->user['level'] < 5) {
+                        foreach (dbFetchRows('SELECT device_id FROM devices_perms WHERE user_id = ?', array($this->user['id'])) as $tmp) {
+                            $this->user['devices'][] = $tmp['device_id'];
+                        }
+
+                        foreach (dbFetchRows('SELECT port_id FROM ports_perms WHERE user_id = ?', array($this->user['id'])) as $tmp) {
+                            $this->user['ports'][] = $tmp['port_id'];
+                        }
+                    }
+                    if ($this->debug) {
+                        $this->log("HostAuth on irc for '".$user['username']."', ID: '".$user_id."', Host: '".$host);
+                    }
+                    return true;
+                }
+            }
+        }
+        return false;
+    }//end hostAuth
 
 
     private function ircRaw($params)
@@ -525,6 +628,8 @@ class IRCBot
         if ($this->user['level'] == 10) {
             global $config;
             $config = array();
+            $config['install_dir'] = $this->config['install_dir'];
+            chdir($config['install_dir']);
             include 'includes/defaults.inc.php';
             include 'config.php';
             include 'includes/definitions.inc.php';
@@ -551,6 +656,7 @@ class IRCBot
     private function _quit($params)
     {
         if ($this->user['level'] == 10) {
+            $this->ircRaw("QUIT :Requested");
             return die();
         } else {
             return $this->respond('Permission denied.');
@@ -707,6 +813,15 @@ class IRCBot
                 $devdown  = array_pop(dbFetchRow("SELECT count(*) FROM devices WHERE status = '0' AND `ignore` = '0'".$d_a));
                 $devign   = array_pop(dbFetchRow("SELECT count(*) FROM devices WHERE `ignore` = '1'".$d_a));
                 $devdis   = array_pop(dbFetchRow("SELECT count(*) FROM devices WHERE `disabled` = '1'".$d_a));
+                if ($devup > 0) {
+                    $devup = $this->_color($devup, 'green');
+                }
+                if ($devdown > 0) {
+                    $devdown = $this->_color($devdown, 'red');
+                    $devcount = $this->_color($devcount, 'yellow', null, 'bold');
+                } else {
+                    $devcount = $this->_color($devcount, 'green', null, 'bold');
+                }
                 $msg      = 'Devices: '.$devcount.' ('.$devup.' up, '.$devdown.' down, '.$devign.' ignored, '.$devdis.' disabled'.')';
                 break;
 
@@ -719,6 +834,15 @@ class IRCBot
                 $prtsht   = array_pop(dbFetchRow("SELECT count(*) FROM ports AS I, devices AS D WHERE I.ifAdminStatus = 'down' AND I.ignore = '0' AND D.device_id = I.device_id AND D.ignore = '0'".$p_a));
                 $prtign   = array_pop(dbFetchRow("SELECT count(*) FROM ports AS I, devices AS D WHERE D.device_id = I.device_id AND (I.ignore = '1' OR D.ignore = '1')".$p_a));
                 $prterr   = array_pop(dbFetchRow("SELECT count(*) FROM ports AS I, devices AS D WHERE D.device_id = I.device_id AND (I.ignore = '0' OR D.ignore = '0') AND (I.ifInErrors_delta > '0' OR I.ifOutErrors_delta > '0')".$p_a));
+                if ($prtup > 0) {
+                    $prtup = $this->_color($prtup, 'green');
+                }
+                if ($prtdown > 0) {
+                    $prtdown = $this->_color($prtdown, 'red');
+                    $prtcount = $this->_color($prtcount, 'yellow', null, 'bold');
+                } else {
+                    $prtcount = $this->_color($prtcount, 'green', null, 'bold');
+                }
                 $msg      = 'Ports: '.$prtcount.' ('.$prtup.' up, '.$prtdown.' down, '.$prtign.' ignored, '.$prtsht.' shutdown'.')';
                 break;
 
@@ -730,6 +854,15 @@ class IRCBot
                 $srvdown  = array_pop(dbFetchRow("SELECT count(service_id) FROM services WHERE service_status = '0' AND service_ignore = '0'".$d_a));
                 $srvign   = array_pop(dbFetchRow("SELECT count(service_id) FROM services WHERE service_ignore = '1'".$d_a));
                 $srvdis   = array_pop(dbFetchRow("SELECT count(service_id) FROM services WHERE service_disabled = '1'".$d_a));
+                if ($srvup > 0) {
+                    $srvup = $this->_color($srvup, 'green');
+                }
+                if ($srvdown > 0) {
+                    $srvdown = $this->_color($srvdown, 'red');
+                    $srvcount = $this->_color($srvcount, 'yellow', null, 'bold');
+                } else {
+                    $srvcount = $this->_color($srvcount, 'green', null, 'bold');
+                }
                 $msg      = 'Services: '.$srvcount.' ('.$srvup.' up, '.$srvdown.' down, '.$srvign.' ignored, '.$srvdis.' disabled'.')';
                 break;
 
@@ -740,4 +873,48 @@ class IRCBot
 
         return $this->respond($msg);
     }//end _status()
+
+    private function _color($text, $fg_color, $bg_color = null, $other = null)
+    {
+        $colors = array(
+            'white' => "00",
+            'black' => "01",
+            'blue' => "02",
+            'green' => "03",
+            'red' => "04",
+            'brown' => "05",
+            'purple' => "06",
+            'orange' => "07",
+            'yellow' => "08",
+            'lightgreen' => "09",
+            'cyan' => "10",
+            'lightcyan' => "11",
+            'lightblue' => "12",
+            'pink' => "13",
+            'grey' => "14",
+            'lightgrey' => "15",
+        );
+        $ret = chr(3);
+        if (array_key_exists($fg_color, $colors)) {
+            $ret .= $colors[$fg_color];
+            if (array_key_exists($bg_color, $colors)) {
+                $ret .= ",".$colors[$fg_color];
+            }
+        }
+        switch ($other) {
+            case 'bold':
+                $ret .= chr(2);
+                break;
+            case 'underline':
+                $ret .= chr(31);
+                break;
+            case 'italics':
+            case 'reverse':
+                $ret .= chr(22);
+                break;
+        }
+        $ret .= $text;
+        $ret .= chr(15);
+        return $ret;
+    }// end _color
 }//end class
