@@ -22,6 +22,7 @@
 # define DAILY_SCRIPT as the full path to this script and LIBRENMS_DIR as the directory this script is in
 DAILY_SCRIPT=$(readlink -f "$0")
 LIBRENMS_DIR=$(dirname "$DAILY_SCRIPT")
+COMPOSER="php ${LIBRENMS_DIR}/scripts/composer_wrapper.php"
 
 # set log_file, using librenms $config['log_dir'], if set
 # otherwise we default to <LibreNMS Install Directory>/logs
@@ -83,7 +84,7 @@ status_run() {
 # Arguments:
 #   args:
 #        Array of arguments to pass to
-#        daily.php 
+#        daily.php
 # Returns:
 #   Exit-Code of Command
 #######################################
@@ -95,12 +96,31 @@ call_daily_php() {
     done
 }
 
+#######################################
+# Set critical notifications for the user
+# Globals:
+#   LIBRENMS_DIR
+# Arguments:
+#   args:
+#        Type: update
+#        Result: 1 for success, 0 for failure
+# Returns:
+#   Exit-Code of Command
+#######################################
+set_notification() {
+    local args="$@";
+    local arg_type=$1;
+    local arg_result=$2;
+
+    php "${LIBRENMS_DIR}/daily.php" -f set_notification -t ${arg_type} -r ${arg_result};
+}
+
 #######################################
 # Entry into program
 # Globals:
 #   LIBRENMS_DIR
 # Arguments:
-#   
+#
 # Returns:
 #   Exit-Code of Command
 #######################################
@@ -113,7 +133,7 @@ main () {
         # only try to su if we are root (or sudo)
         if [[ "$EUID" -eq 0 ]]; then
             echo "Re-running ${DAILY_SCRIPT} as ${LIBRENMS_USER} user"
-            su -l "$LIBRENMS_USER" -c "$DAILY_SCRIPT $@"
+            sudo -u "$LIBRENMS_USER" "$DAILY_SCRIPT" "$@"
             exit;
         fi
 
@@ -122,26 +142,51 @@ main () {
         fi
     fi
 
+    # make sure autoload.php exists before trying to run any php that may require it
+    if [ ! -f "${LIBRENMS_DIR}/vendor/autoload.php" ]; then
+        ${COMPOSER} install --no-dev
+    fi
+
     if [[ -z "$arg" ]]; then
         up=$(/usr/local/bin/php-5.6 daily.php -f update >&2; echo $?)
         if [[ "$up" == "0" ]]; then
-            $DAILY_SCRIPT no-code-update
+            ${DAILY_SCRIPT} no-code-update
+            set_notification update 1  # make sure there are no update notifications if update is disabled
             exit
-        elif [[ "$up" == "1" ]]; then
+        fi
+
+        # make sure the vendor directory is clean
+        git checkout vendor/ --quiet > /dev/null 2>&1
+
+        update_res=0
+        if [[ "$up" == "1" ]]; then
             # Update to Master-Branch
             old_ver=$(git show --pretty="%H" -s HEAD)
             status_run 'Updating to latest codebase' 'git pull --quiet' 'update'
+            update_res=$?
             new_ver=$(git show --pretty="%H" -s HEAD)
-            if [ "$old_ver" != "$new_ver" ]; then
-                status_run "Updated from $old_ver to $new_ver" ''
-            fi
         elif [[ "$up" == "3" ]]; then
             # Update to last Tag
             old_ver=$(git describe --exact-match --tags $(git log -n1 --pretty='%h'))
             status_run 'Updating to latest release' 'git fetch --tags && git checkout $(git describe --tags $(git rev-list --tags --max-count=1))' 'update'
+            update_res=$?
             new_ver=$(git describe --exact-match --tags $(git log -n1 --pretty='%h'))
-            if [[ "$old_ver" != "$new_ver" ]]; then
+        fi
+
+        if (( $update_res > 0 )); then
+            set_notification update 0
+        fi
+
+        if [[ "$old_ver" != "$new_ver" ]]; then
+#            status_run 'Updating Composer packages' "${COMPOSER} install --no-dev" 'update'
+
+            # Run post update checks
+            if [ ! -f "${LIBRENMS_DIR}/vendor/autoload.php" ]; then
+                status_run "Reverting update, check the output of composer diagnose" "git checkout $old_ver" 'update'
+                set_notification update 0
+            else
                 status_run "Updated from $old_ver to $new_ver" ''
+                set_notification update 1  # only clear the error if update was a success
             fi
         fi
 
@@ -154,7 +199,7 @@ main () {
 
         if [[ -z "$cnf" ]] || [[ "$cnf" == "0" ]] || [[ "$cnf" == "false" ]]; then
             # Call ourself again in case above pull changed or added something to daily.sh
-            $DAILY_SCRIPT post-pull
+            ${DAILY_SCRIPT} post-pull
         fi
     else
         case $arg in
@@ -178,7 +223,7 @@ main () {
                                "syslog"
                                "eventlog"
                                "authlog"
-                               "perf_time"
+                               "perf_times"
                                "callback"
                                "device_perf"
                                "purgeusers"
