@@ -51,6 +51,7 @@ function get_graph_by_port_hostname()
     $app          = \Slim\Slim::getInstance();
     $router       = $app->router()->getCurrentRoute()->getParams();
     $hostname     = $router['hostname'];
+    $device_id    = ctype_digit($hostname) ? $hostname : getidbyname($hostname);
     $vars         = array();
     $vars['port'] = urldecode($router['ifname']);
     $vars['type'] = $router['type'] ?: 'port_bits';
@@ -71,7 +72,7 @@ function get_graph_by_port_hostname()
     $vars['width']  = $_GET['width'] ?: 1075;
     $vars['height'] = $_GET['height'] ?: 300;
     $auth           = '1';
-    $vars['id']     = dbFetchCell("SELECT `P`.`port_id` FROM `ports` AS `P` JOIN `devices` AS `D` ON `P`.`device_id` = `D`.`device_id` WHERE `D`.`hostname`=? AND `P`.`$port`=? AND `deleted` = 0 LIMIT 1", array($hostname, $vars['port']));
+    $vars['id']     = dbFetchCell("SELECT `P`.`port_id` FROM `ports` AS `P` JOIN `devices` AS `D` ON `P`.`device_id` = `D`.`device_id` WHERE `D`.`device_id`=? AND `P`.`$port`=? AND `deleted` = 0 LIMIT 1", array($device_id, $vars['port']));
     $app->response->headers->set('Content-Type', get_image_type());
     rrdtool_initialize(false);
     include 'includes/graphs/graph.inc.php';
@@ -220,6 +221,9 @@ function list_devices()
         $sql = "`status`='0' AND `ignore`='0' AND `disabled`='0'";
     } elseif ($type == 'disabled') {
         $sql = "`disabled`='1'";
+    } elseif ($type == 'os') {
+        $sql = "`os`=?";
+        $param[] = $query;
     } elseif ($type == 'mac') {
         $join = " LEFT JOIN `ports` ON `devices`.`device_id`=`ports`.`device_id` LEFT JOIN `ipv4_mac` ON `ports`.`port_id`=`ipv4_mac`.`port_id` ";
         $sql = "`ipv4_mac`.`mac_address`=?";
@@ -1465,31 +1469,40 @@ function list_arp()
     $code     = 404;
     $message  = '';
     $ip       = $router['ip'];
+    $hostname = mres($_GET['device']);
     $total    = 0;
     if (empty($ip)) {
         $message = "No valid IP provided";
+    } elseif ($ip === "all" && empty($hostname)) {
+        $message = "Device argument is required when requesting all entries";
     } else {
         $code = 200;
         $status = 'ok';
         if ($ip === "all") {
-            $hostname =  mres($_GET['device']);
             $device_id = ctype_digit($hostname) ? $hostname : getidbyname($hostname);
             $arp = dbFetchRows("SELECT `ipv4_mac`.* FROM `ipv4_mac` LEFT JOIN `ports` ON `ipv4_mac`.`port_id` = `ports`.`port_id` WHERE `ports`.`device_id` = ?", array($device_id));
+        } elseif (str_contains($ip, '/')) {
+            list($net, $cidr) = explode('/', $ip, 2);
+            $arp = dbFetchRows(
+                'SELECT * FROM `ipv4_mac` WHERE (inet_aton(`ipv4_address`) & ?) = ?',
+                array(cidr2long($cidr), ip2long($net))
+            );
         } else {
             $arp = dbFetchRows("SELECT * FROM `ipv4_mac` WHERE `ipv4_address`=?", array($ip));
         }
-        $total  = count($arp);
+        $total = count($arp);
     }
     $output  = array(
         'status'  => $status,
         'err-msg' => $message,
         'count'   => $total,
-        'arp'  => $arp,
+        'arp'     => $arp,
     );
     $app->response->setStatus($code);
     $app->response->headers->set('Content-Type', 'application/json');
     echo _json_encode($output);
 }
+
 function list_services()
 {
     global $config;
@@ -1498,16 +1511,16 @@ function list_services()
     $status   = 'ok';
     $code     = 200;
     $message  = '';
-    $host_par = array();
-    $sql_param = array();
     $services = array();
-    $where    = '';
-    $devicewhere = '';
+    $where    = array();
+    $params   = array();
 
-    // Filter BY STATE
+    // Filter by State
     if (isset($_GET['state'])) {
-        $where  = " AND S.service_status= ? AND S.service_disabled='0' AND S.service_ignore='0'";
-        $host_par[] = $_GET['state'];
+        $where[] = '`service_status`=?';
+        $params[] = $_GET['state'];
+        $where[] = "`service_disabled`='0'";
+        $where[] = "`service_ignore`='0'";
 
         if (!is_numeric($_GET['state'])) {
             $status   = 'error';
@@ -1515,13 +1528,18 @@ function list_services()
         }
     }
 
-    // GET BY HOST
+    //Filter by Type
+    if (isset($_GET['type'])) {
+        $where[] = '`service_type` LIKE ?';
+        $params[] = $_GET['type'];
+    }
+
+    //GET by Host
     if (isset($router['hostname'])) {
         $hostname = $router['hostname'];
         $device_id = ctype_digit($hostname) ? $hostname : getidbyname($hostname);
-
-        $where .= " AND S.device_id = ?";
-        $host_par[] = $device_id;
+        $where[] = '`device_id` = ?';
+        $params[] = $device_id;
 
         if (!is_numeric($device_id)) {
             $status   = 'error';
@@ -1529,22 +1547,14 @@ function list_services()
         }
     }
 
-    // DEVICE
-    $host_sql = 'SELECT * FROM devices AS D, services AS S WHERE D.device_id = S.device_id '.$where.' GROUP BY D.hostname ORDER BY D.hostname';
+    $query = 'SELECT * FROM `services`';
 
-    // SERVICE
-    foreach (dbFetchRows($host_sql, $host_par) as $device) {
-        $device_id = $device['device_id'];
-        $sql_param[0] = $device_id;
-
-        // FILTER BY TYPE
-        if (isset($_GET['type'])) {
-            $devicewhere  = " AND `service_type` LIKE ?";
-            $sql_param[1] = $_GET['type'];
-        }
-
-        $services[] = dbFetchRows("SELECT * FROM `services` WHERE `device_id` = ?".$devicewhere, $sql_param);
+    if (!empty($where)) {
+        $query .= ' WHERE ' . implode(' AND ', $where);
     }
+    $query .= ' ORDER BY `service_ip`';
+    $services = array(dbFetchRows($query, $params)); // double array for backwards compat :(
+
     $count = count($services);
     $output = array(
         'status'  => $status,
@@ -1557,3 +1567,76 @@ function list_services()
     $app->response->headers->set('Content-Type', 'application/json');
     echo _json_encode($output);
 }
+
+function list_logs()
+{
+    global $config;
+    $app = \Slim\Slim::getInstance();
+    $router = $app->router()->getCurrentRoute()->getParams();
+    $type = $app->router()->getCurrentRoute()->getName();
+    $hostname = $router['hostname'];
+    $device_id = ctype_digit($hostname) ? $hostname : getidbyname($hostname);
+    if ($type === 'list_eventlog') {
+        $table = 'eventlog';
+        $timestamp = 'datetime';
+    } elseif ($type === 'list_syslog') {
+        $table = 'syslog';
+        $timestamp = 'timestamp';
+    } elseif ($type === 'list_alertlog') {
+        $table = 'alert_log';
+        $timestamp = 'time_logged';
+    } elseif ($type === 'list_authlog') {
+        $table = 'authlog';
+        $timestamp = 'datetime';
+    } else {
+        $table = 'eventlog';
+        $timestamp = 'datetime';
+    }
+
+    $message = '';
+    $status = 'ok';
+    $code = 200;
+    $start = mres($_GET['start']) ?: 1;
+    $limit = mres($_GET['limit']) ?: 50;
+    $from = mres($_GET['from']);
+    $to = mres($_GET['to']);
+
+    $count_query = 'SELECT COUNT(*)';
+    $full_query = "SELECT `devices`.`hostname`, `devices`.`sysName`, `$table`.*";
+
+    $param = array();
+    $query = " FROM $table LEFT JOIN `devices` ON `$table`.`device_id`=`devices`.`device_id` WHERE 1";
+
+    if (is_numeric($device_id)) {
+        $query .= " AND `devices`.`device_id` = ?";
+        $param[] = $device_id;
+    }
+
+    if ($from) {
+        $query .= " AND $timestamp >= ?";
+        $param[] = $from;
+    }
+
+    if ($to) {
+        $query .= " AND $timestamp <= ?";
+        $param[] = $to;
+    }
+
+    $count_query = $count_query . $query;
+    $count = dbFetchCell($count_query, $param);
+    $full_query = $full_query . $query . " ORDER BY $timestamp ASC LIMIT $start,$limit";
+    $logs = dbFetchRows($full_query, $param);
+
+    $limited_count = count($logs);
+    $output = array(
+        'status' => $status,
+        'err-msg' => $message,
+        'count' => $limited_count,
+        'total' => $count,
+        'logs' => $logs,
+    );
+
+    $app->response->setStatus($code);
+    $app->response->headers->set('Content-Type', 'application/json');
+    echo _json_encode($output);
+}
