@@ -17,7 +17,7 @@ if (defined('SHOW_SETTINGS') || empty($widget_settings)) {
     <form class="form-horizontal" onsubmit="widget_settings(this); return false;">
         <div class="form-group">
             <div class="col-sm-12">
-                html is supported here. If you want just text then wrap in &lt;pre&gt;&lt;/pre&gt;
+                The following html tags are supported: &lt;b&gt;, &lt;iframe&gt;, &lt;i&gt;, &lt;ul&gt;, &lt;li&gt;, &lt;h1&gt;, &lt;h2&gt;, &lt;h3&gt;, &lt;h4&gt;, &lt;br&gt;, &lt;p&gt;. If you want just text then wrap in &lt;pre&gt;&lt;/pre&gt;
             </div>
         </div>
         <div class="form-group">
@@ -33,5 +33,15 @@ if (defined('SHOW_SETTINGS') || empty($widget_settings)) {
         </div>
     </form>';
 } else {
-    $common_output[] = nl2br(display($widget_settings['notes']));
+    $tmp_config = array(
+        'HTML.Allowed'    => 'b,iframe,i,ul,li,h1,h2,h3,h4,br,p',
+        'HTML.AllowedAttributes'    => 'iframe@src,iframe@width,iframe@height',
+        'HTML.AllowedElements' => array('iframe'),
+        'HTML.Trusted'    => true,
+        'HTML.SafeIframe' => true,
+        'URI.SafeIframeRegexp' => '%^(https?:)?//%',
+    );
+    $common_output[] = display(nl2br($widget_settings['notes']), $tmp_config);
+    //print_r($common_output);exit;
+    unset($tmp_config);
 }
