@@ -12,7 +12,14 @@ $printtotal    = 0;
 $addarea       = 1;
 $transparency  = 15;
 
-$rrd_filename = rrd_name($device['hostname'], array('app', $name, $app_id));
+
+if (isset($vars['database'])) {
+    $rrd_name_array=array('app', $name, $app_id, $vars['database']);
+} else {
+    $rrd_name_array=array('app', $name, $app_id);
+}
+
+$rrd_filename = rrd_name($device['hostname'], $rrd_name_array);
 
 if (is_file($rrd_filename)) {
     $rrd_list = array(
