@@ -4,7 +4,7 @@ require 'includes/graphs/common.inc.php';
 
 $rrdfilename = rrd_name($device['hostname'], 'siklu-wireless');
 
-if (file_exists($rrdfilename)) {
+if (rrdtool_check_rrd_exists($rrdfilename)) {
     $rrd_options .= " COMMENT:'db                        Now    Min     Max\\n'";
     $rrd_options .= ' DEF:rfAverageCinr='.$rrdfilename.':rfAverageCinr:AVERAGE ';
     $rrd_options .= " LINE1:rfAverageCinr#CC0000:'CINR                 ' ";
