@@ -6,7 +6,7 @@ $rrd_options .= ' -l 0 -E ';
 
 $rrdfilename = rrd_name($device['hostname'], 'ubnt-airmax-mib');
 
-if (file_exists($rrdfilename)) {
+if (rrdtool_check_rrd_exists($rrdfilename)) {
     $rrd_options .= " COMMENT:'                           Now    Min     Max\\n'";
     $rrd_options .= ' DEF:RadioFreq='.$rrdfilename.':RadioFreq:AVERAGE ';
     $rrd_options .= " LINE1:RadioFreq#CC0000:'Frequency            ' ";
