@@ -9,7 +9,7 @@ $rrd_options .= ' -l 0 -E ';
 
 $rrdfilename = rrd_name($device['hostname'], 'ubnt-airmax-mib');
 
-if (file_exists($rrdfilename)) {
+if (rrdtool_check_rrd_exists($rrdfilename)) {
     $rrd_options .= " COMMENT:'dbm                        Now    Min     Max\\n'";
     $rrd_options .= ' DEF:RadioTxPower='.$rrdfilename.':RadioTxPower:AVERAGE ';
     $rrd_options .= " LINE1:RadioTxPower#CC0000:'Tx Power             ' ";
