@@ -20,7 +20,7 @@ if (!isset($vars['device'])) {
 }
 
 if ($entry['type'] == 'interface') {
-    $this_if       = ifLabel(getifbyid($entry['reference']));
+    $this_if       = cleanPort(getifbyid($entry['reference']));
     $entry['link'] = '<b>'.generate_port_link($this_if, makeshortif(strtolower($this_if['label']))).'</b>';
 } else {
     $entry['link'] = 'System';
