@@ -23,7 +23,7 @@ if ($_SESSION['userlevel'] < '10') {
     }
 
     foreach (dbFetchRows('SELECT * FROM `devices` ORDER BY `hostname`') as $device) {
-        $devicesform .= "<option value='".$device['device_id']."'>".$device['hostname'].'</option>';
+        $devicesform .= "<option value='".$device['device_id']."'>".format_hostname($device).'</option>';
     }
 
     if ($updated) {
