@@ -33,33 +33,38 @@ foreach ($vrfs_lite_cisco as $vrf) {
     $context = $vrf['context_name'];
     $device['context_name']=$context;
 
-    $arp_data = snmpwalk_cache_multi_oid($device, 'ipNetToPhysicalPhysAddress', array(), 'IP-MIB');
-    $arp_data = snmpwalk_cache_multi_oid($device, 'ipNetToMediaPhysAddress', $arp_data, 'IP-MIB');
-
-    $sql = "SELECT M.* from ipv4_mac AS M, ports AS I WHERE M.port_id=I.port_id AND I.device_id=? AND M.context_name=?";
-    $params = array($device['device_id'], $context);
-    $existing_data = dbFetchRows($sql, $params);
-    $ipv4_addresses = array();
-    foreach ($existing_data as $data) {
-        $ipv4_addresses[] = $data['ipv4_address'];
+    if (file_exists($config['install_dir'] . "/includes/discovery/arp-table/{$device['os']}.inc.php")) {
+        include $config['install_dir'] . "/includes/discovery/arp-table/{$device['os']}.inc.php";
+    } else {
+        $arp_data = snmpwalk_group($device, 'ipNetToPhysicalPhysAddress', 'IP-MIB');
+        $arp_data = snmpwalk_group($device, 'ipNetToMediaPhysAddress', 'IP-MIB', 1, $arp_data);
     }
 
+    $existing_data = dbFetchRows(
+        "SELECT * from `ipv4_mac` WHERE `device_id`=? AND `context_name`=?",
+        array($device['device_id'], $context)
+    );
+    $ipv4_addresses = array_map(function ($data) {
+        return $data['ipv4_address'];
+    }, $existing_data);
+
     $arp_table = array();
     $insert_data = array();
-    foreach ($arp_data as $ip => $data) {
-        if (isset($data['ipNetToPhysicalPhysAddress'])) {
-            $raw_mac = $data['ipNetToPhysicalPhysAddress'];
-            list($if, $ipv, $ip) = explode('.', $ip, 3);
-        } elseif (isset($data['ipNetToMediaPhysAddress'])) {
-            $raw_mac = $data['ipNetToMediaPhysAddress'];
-            list($if, $ip)  = explode('.', $ip, 2);
-            $ipv = 'ipv4';
-        }
-
-        $interface = get_port_by_index_cache($device['device_id'], $if);
+    foreach ($arp_data as $ifIndex => $data) {
+        $interface = get_port_by_index_cache($device['device_id'], $ifIndex);
         $port_id = $interface['port_id'];
 
-        if (!empty($ip) && $ipv === 'ipv4' && !empty($raw_mac) && $raw_mac != '0:0:0:0:0:0' && !isset($arp_table[$port_id][$ip])) {
+        $port_arp = array_merge(
+            (array)$data['ipNetToMediaPhysAddress'],
+            (array)$data['ipNetToPhysicalPhysAddress']['ipv4']
+        );
+
+        echo "{$interface['ifName']}: \n";
+        foreach ($port_arp as $ip => $raw_mac) {
+            if (empty($ip) || empty($raw_mac) || $raw_mac == '0:0:0:0:0:0' || isset($arp_table[$port_id][$ip])) {
+                continue;
+            }
+
             $mac = implode(array_map('zeropad', explode(':', $raw_mac)));
             $arp_table[$port_id][$ip] = $mac;
 
@@ -71,24 +76,23 @@ foreach ($vrfs_lite_cisco as $vrf) {
                     log_event("MAC change: $ip : " . mac_clean_to_readable($old_mac) . ' -> ' . mac_clean_to_readable($mac), $device, 'interface', 4, $port_id);
                     dbUpdate(array('mac_address' => $mac), 'ipv4_mac', 'port_id=? AND ipv4_address=? AND context_name=?', array($port_id, $ip, $context));
                 }
-                d_echo(null, '.');
+                d_echo("$raw_mac => $ip\n", '.');
             } elseif (isset($interface['port_id'])) {
-                d_echo(null, '+');
+                d_echo("$raw_mac => $ip\n", '+');
                 $insert_data[] = array(
                     'port_id'      => $port_id,
+                    'device_id'    => $device['device_id'],
                     'mac_address'  => $mac,
                     'ipv4_address' => $ip,
                     'context_name' => $context,
                 );
             }
         }
-
-        unset(
-            $interface
-        );
+        echo PHP_EOL;
     }
 
     unset(
+        $interface,
         $arp_data,
         $ipv4_addresses,
         $data
@@ -109,6 +113,13 @@ foreach ($vrfs_lite_cisco as $vrf) {
             d_echo(null, '-');
         }
     }
+
+    // remove entries that no longer have an owner
+    dbQuery('DELETE `ipv4_mac` FROM `ipv4_mac`
+ LEFT JOIN `ports` ON `ipv4_mac`.`port_id` = `ports`.`port_id` 
+ LEFT JOIN `devices` ON `ipv4_mac`.`device_id` = `devices`.`device_id` 
+ WHERE `ports`.`port_id` IS NULL OR `devices`.`device_id` IS NULL');
+
     echo PHP_EOL;
     unset(
         $existing_data,
