@@ -14,9 +14,9 @@
 if ($device['os'] == 'comware') {
     echo 'HPE Comware ';
 
-    $entity_data = snmpwalk_cache_oid($device, 'entPhysicalName', array(), 'ENTITY-MIB');
+    $entity_data = snmpwalk_cache_oid($device, 'entPhysicalClass', array(), 'ENTITY-MIB');
     $indexes = array_keys(array_filter($entity_data, function ($entry) {
-        return $entry['entPhysicalName'] == 'Board';
+        return $entry['entPhysicalClass'] == 'module';
     }));
 
     if (!empty($indexes)) {
@@ -27,7 +27,9 @@ if ($device['os'] == 'comware') {
                 $cur_oid = ".1.3.6.1.4.1.25506.2.6.1.1.1.1.6.$entIndex";
                 $cur_value = $procdata[$entIndex]['hh3cEntityExtCpuUsage'];
                 $descr = 'Slot ' . ++$i;
-                discover_processor($valid['processor'], $device, $cur_oid, $entIndex, 'comware', $descr, '1', $cur_value);
+                if ($cur_value > 0) {
+                    discover_processor($valid['processor'], $device, $cur_oid, $entIndex, 'comware', $descr, '1', $cur_value);
+                }
             }
         }
     }
