@@ -34,13 +34,16 @@ $entitysensor['dBm']       = 'dbm';
 
 if (is_array($oids)) {
     foreach ($oids as $index => $entry) {
-        // echo("[" . $entry['entPhySensorType'] . "|" . $entry['entPhySensorValue']. "|" . $index . "]");
+        // Fix for Cisco ASR920, 15.5(2)S
+        if ($entry['entPhySensorType'] == 'other' && str_contains($entity_array[$index]['entPhysicalName'], array('Rx Power Sensor', 'Tx Power Sensor'))) {
+            $entitysensor['other'] = 'dbm';
+        }
         if ($entitysensor[$entry['entPhySensorType']] && is_numeric($entry['entPhySensorValue']) && is_numeric($index)) {
             $entPhysicalIndex = $index;
             $oid              = '.1.3.6.1.2.1.99.1.1.1.4.'.$index;
             $current          = $entry['entPhySensorValue'];
             // ENTITY-SENSOR-MIB::entPhySensorUnitsDisplay.11 = STRING: "C"
-            $descr = $entity_array[$index]['entPhysicalName'];
+            $descr = ucwords($entity_array[$index]['entPhysicalName']);
             // if ($descr || $device['os'] == "iosxr")
             if ($descr) {
                 $descr = rewrite_entity_descr($descr);
@@ -106,6 +109,21 @@ if (is_array($oids)) {
                 } $descr = preg_replace('/[T|t]emperature[|s]/', '', $descr);
             }
 
+            if ($device['os'] == 'rittal-lcp') {
+                if ($type == 'voltage') {
+                    $divisor = 1000;
+                }
+                if ($descr == 'Temperature.Value') {
+                    $divisor = 1000;
+                }
+                if ($descr == 'System.Temperature.Value') {
+                    $divisor = 1000;
+                }
+                if ($type == 'humidity' && $current == '0') {
+                    $valid_sensor = false;
+                }
+            }
+
             // echo($descr . "|" . $index . "|" .$current . "|" . $multiplier . "|" . $divisor ."|" . $entry['entPhySensorScale'] . "|" . $entry['entPhySensorPrecision'] . "\n");
             if ($current == '-127' || ($device['os'] == 'asa' && str_contains($device['hardware'], 'sc'))) {
                 $valid_sensor = false;
@@ -115,7 +133,7 @@ if (is_array($oids)) {
                 // Check to make sure we've not already seen this sensor via cisco's entity sensor mib
                 if ($type == "power" && $device['os'] == "arista_eos" && preg_match("/DOM (R|T)x Power/i", $descr)) {
                     $type = "dbm";
-                    $current = round(10 * log10($sensor_value / 10000), 3);
+                    $current = round(10 * log10($entry['entPhySensorValue'] / 10000), 3);
                     $multiplier = 1;
                     $divisor = 1;
                     discover_sensor($valid['sensor'], $type, $device, $oid, $index, 'entity-sensor', $descr, $divisor, $multiplier, null, null, null, null, $current, 'snmp', $entPhysicalIndex, $entry['entSensorMeasuredEntity']);
