@@ -1,7 +1,7 @@
 <?php
 
 echo 'AVTECH: ';
-if (strpos($device['sysObjectID'], '.20916.1.9') !== false) {
+if (ends_with($device['sysObjectID'], '.20916.1.9')) {
     //  RoomAlert 3E
     $device_oid = '.1.3.6.1.4.1.20916.1.9.';
 
@@ -11,8 +11,8 @@ if (strpos($device['sysObjectID'], '.20916.1.9') !== false) {
         'oid'       => $device_oid.'1.2.1.0',
         'descr_oid' => $device_oid.'1.2.2.0',
     );
-    avtech_add_sensor($device, $switch);
-} elseif (strpos($device['sysObjectID'], '.20916.1.6') !== false) {
+    avtech_add_sensor($device, $switch, $valid);
+} elseif (ends_with($device['sysObjectID'], '.20916.1.6')) {
     //  RoomAlert 4E
     $device_oid = '.1.3.6.1.4.1.20916.1.6.';
 
@@ -22,5 +22,5 @@ if (strpos($device['sysObjectID'], '.20916.1.9') !== false) {
         'oid'       => $device_oid.'1.3.1.0',
         'descr_oid' => $device_oid.'1.3.2.0',
     );
-    avtech_add_sensor($device, $switch);
+    avtech_add_sensor($device, $switch, $valid);
 }
