@@ -4,16 +4,13 @@
  * requires snmp extend agent script from librenms-agent
  */
 
-$raspberry = snmp_get($device, 'HOST-RESOURCES-MIB::hrSystemInitialLoadParameters.0', '-Osqnv');
-
-if (preg_match("/(bcm).+(boardrev)/", $raspberry)) {
+$sensor_oid = ".1.3.6.1.4.1.8072.1.3.2.4.1.2.9.114.97.115.112.98.101.114.114.121.1";
+$value = snmp_get($device, $sensor_oid, '-Oqve');
+$value = trim($value, '"');
+if (is_numeric($value)) {
     $sensor_type = "raspberry_temp";
-    $sensor_oid = ".1.3.6.1.4.1.8072.1.3.2.4.1.2.9.114.97.115.112.98.101.114.114.121.1";
     $descr = "CPU Temp";
-    $value = snmp_get($device, $sensor_oid, '-Oqve');
-    if (is_numeric($value)) {
-        discover_sensor($valid['sensor'], 'temperature', $device, $sensor_oid, 1, $sensor_type, $descr, 1, 1, null, null, null, null, $value);
-    }
+    discover_sensor($valid['sensor'], 'temperature', $device, $sensor_oid, 1, $sensor_type, $descr, 1, 1, null, null, null, null, $value);
 }
 
 if (starts_with($sysObjectId, '.1.3.6.1.4.1.232.')) {
@@ -28,7 +25,7 @@ if (starts_with($sysObjectId, '.1.3.6.1.4.1.232.')) {
             $temperature_id = $split_oid[(count($split_oid) - 2)] . '.' . $split_oid[(count($split_oid) - 1)];
 
             $descr_oid = ".1.3.6.1.4.1.232.6.2.6.8.1.3.$temperature_id";
-            $descr = snmp_get($device, $descr_oid, '-Oqnv', 'CPQHLTH-MIB');
+            $descr = snmp_get($device, $descr_oid, '-Oqnv', 'CPQHLTH-MIB', 'hp');
 
             $temperature_oid = ".1.3.6.1.4.1.232.6.2.6.8.1.4.$temperature_id";
             $temperature = snmp_get($device, $temperature_oid, '-Oqv', '');
@@ -43,4 +40,19 @@ if (starts_with($sysObjectId, '.1.3.6.1.4.1.232.')) {
     }
 }
 
+$chip = snmp_get($device, '.1.3.6.1.2.1.1.1.0', '-Oqv');
+
+if (preg_match("/(Linux).+(ntc)/", $chip)) {
+    $sensor_type = "chip_axp209_temperature";
+    $oid = '.1.3.6.1.4.1.8072.1.3.2.4.1.2.10.112.111.119.101.114.45.115.116.97.';
+    $lowlimit     = -40;
+    $lowwarnlimit = -35;
+    $warnlimit    = 120;
+    $limit        = 130;
+    $descr = 'AXP209 Temperature';
+    $index = '116.1';
+    $value = snmp_get($device, $oid.$index, '-Oqv');
+    discover_sensor($valid['sensor'], 'temperature', $device, $oid.$index, $index, $sensor_type, $descr, '1', '1', $lowlimit, $lowwarnlimit, $warnlimit, $limit, $value);
+}
+
 include_once $config['install_dir'] . '/includes/discovery/sensors/temperature/supermicro.inc.php';
