@@ -27,66 +27,75 @@
  * @param array $modules Which modules to initialize
  */
 
+global $config;
+
 $install_dir = realpath(__DIR__ . '/..');
 $config['install_dir'] = $install_dir;
 chdir($install_dir);
 
-if (!getenv('TRAVIS')) {
-    require('Net/IPv4.php');
-    require('Net/IPv6.php');
-}
-
 # composer autoload
 require $install_dir . '/vendor/autoload.php';
 if (version_compare(PHP_VERSION, '5.4', '>=')) {
-    require $install_dir . '/lib/influxdb-php/vendor/autoload.php';
+    require_once $install_dir . '/lib/influxdb-php/vendor/autoload.php';
+}
+
+if (!function_exists('module_selected')) {
+    function module_selected($module, $modules)
+    {
+        return in_array($module, (array) $modules);
+    }
 }
 
 // function only files
 require_once $install_dir . '/includes/common.php';
-require $install_dir . '/includes/dbFacile.php';
-require $install_dir . '/includes/rrdtool.inc.php';
-require $install_dir . '/includes/influxdb.inc.php';
-require $install_dir . '/includes/graphite.inc.php';
-require $install_dir . '/includes/datastore.inc.php';
-require $install_dir . '/includes/billing.php';
-require $install_dir . '/includes/syslog.php';
+require_once $install_dir . '/includes/dbFacile.php';
+require_once $install_dir . '/includes/rrdtool.inc.php';
+require_once $install_dir . '/includes/influxdb.inc.php';
+require_once $install_dir . '/includes/opentsdb.inc.php';
+require_once $install_dir . '/includes/graphite.inc.php';
+require_once $install_dir . '/includes/datastore.inc.php';
+require_once $install_dir . '/includes/billing.php';
+require_once $install_dir . '/includes/syslog.php';
 if (module_selected('mocksnmp', $init_modules)) {
-    require $install_dir . '/tests/mocks/mock.snmp.inc.php';
+    require_once $install_dir . '/tests/mocks/mock.snmp.inc.php';
 } else {
-    require $install_dir . '/includes/snmp.inc.php';
+    require_once $install_dir . '/includes/snmp.inc.php';
 }
-require $install_dir . '/includes/services.inc.php';
-require $install_dir . '/includes/mergecnf.inc.php';
-require $install_dir . '/includes/functions.php';
-require $install_dir . '/includes/rewrites.php';  // FIXME both definitions and functions
+require_once $install_dir . '/includes/services.inc.php';
+require_once $install_dir . '/includes/mergecnf.inc.php';
+require_once $install_dir . '/includes/functions.php';
+require_once $install_dir . '/includes/rewrites.php';
 
 if (module_selected('web', $init_modules)) {
     chdir($install_dir . '/html');
-    require $install_dir . '/html/includes/functions.inc.php';
+    require_once $install_dir . '/html/includes/functions.inc.php';
 }
 
 if (module_selected('discovery', $init_modules)) {
-    require $install_dir . '/includes/discovery/functions.inc.php';
+    require_once $install_dir . '/includes/discovery/functions.inc.php';
 }
 
 if (module_selected('polling', $init_modules)) {
     require_once $install_dir . '/includes/device-groups.inc.php';
-    require $install_dir . '/includes/polling/functions.inc.php';
+    require_once $install_dir . '/includes/polling/functions.inc.php';
 }
 
 if (module_selected('alerts', $init_modules)) {
     require_once $install_dir . '/includes/device-groups.inc.php';
-    require $install_dir . '/includes/alerts.inc.php';
+    require_once $install_dir . '/includes/alerts.inc.php';
 }
 
-
 // variable definitions
 require $install_dir . '/includes/cisco-entities.php';
 require $install_dir . '/includes/vmware_guestid.inc.php';
 require $install_dir . '/includes/defaults.inc.php';
 require $install_dir . '/includes/definitions.inc.php';
+
+// Display config.php errors instead of http 500
+$display_bak = ini_get('display_errors');
+ini_set('display_errors', 1);
 include $install_dir . '/config.php';
+ini_set('display_errors', $display_bak);
 
 // init memcached
 if ($config['memcached']['enable'] === true) {
@@ -102,17 +111,30 @@ if ($config['memcached']['enable'] === true) {
 }
 
 if (!module_selected('nodb', $init_modules)) {
+    // Check for testing database
+    if (getenv('DBTEST')) {
+        if (isset($config['test_db_name'])) {
+            $config['db_name'] = $config['test_db_name'];
+        }
+        if (isset($config['test_db_user'])) {
+            $config['db_user'] = $config['test_db_user'];
+        }
+        if (isset($config['test_db_pass'])) {
+            $config['db_pass'] = $config['test_db_pass'];
+        }
+    }
+
     // Connect to database
-    $database_link = mysqli_connect('p:' . $config['db_host'], $config['db_user'], $config['db_pass'], null, $config['db_port']);
-    if (!$database_link) {
-        echo '<h2>MySQL Error</h2>';
-        echo mysqli_connect_error();
-        die;
+    try {
+        dbConnect();
+    } catch (\LibreNMS\Exceptions\DatabaseConnectException $e) {
+        if (isCli()) {
+            echo 'MySQL Error: ' . $e->getMessage() . PHP_EOL;
+        } else {
+            echo "<h2>MySQL Error</h2><p>" . $e->getMessage() . "</p>";
+        }
+        exit(2);
     }
-    $database_db = mysqli_select_db($database_link, $config['db_name']);
-    dbQuery("SET NAMES 'utf8'");
-    dbQuery("SET CHARACTER SET 'utf8'");
-    dbQuery("SET COLLATION_CONNECTION = 'utf8_unicode_ci'");
 
     // pull in the database config settings
     mergedb();
@@ -124,8 +146,10 @@ if (!module_selected('nodb', $init_modules)) {
     require $install_dir . '/includes/process_config.inc.php';
 }
 
-if (file_exists($config['install_dir'] . '/html/includes/authentication/'.$config['auth_mechanism'].'.inc.php')) {
-    require $config['install_dir'] . '/html/includes/authentication/'.$config['auth_mechanism'].'.inc.php';
+if (file_exists($install_dir . '/html/includes/authentication/'.$config['auth_mechanism'].'.inc.php')) {
+    require_once $install_dir . '/html/includes/authentication/functions.php';
+    require_once $install_dir . '/html/includes/authentication/'.$config['auth_mechanism'].'.inc.php';
+    init_auth();
 } else {
     print_error('ERROR: no valid auth_mechanism defined!');
     exit();
@@ -137,12 +161,11 @@ if (module_selected('web', $init_modules)) {
         $config['title_image'] = 'images/librenms_logo_'.$config['site_style'].'.svg';
     }
     require $install_dir . '/html/includes/vars.inc.php';
-    $tmp_list = dbFetchRows('SELECT DISTINCT(`os`) FROM `devices`');
-    $os_list = array();
-    foreach ($tmp_list as $k => $v) {
-        $os_list[] = $config['install_dir'].'/includes/definitions/'. $v['os'] . '.yaml';
+    if (module_selected('nodb', $init_modules)) {
+        load_all_os(false);
+    } else {
+        load_all_os(true);
     }
-    load_all_os($os_list);
 }
 
 $console_color = new Console_Color2();
@@ -156,8 +179,3 @@ if (module_selected('auth', $init_modules) ||
 ) {
     require $install_dir . '/html/includes/authenticate.inc.php';
 }
-
-function module_selected($module, $modules)
-{
-    return in_array($module, (array) $modules);
-}
