@@ -5,7 +5,7 @@
 use LibreNMS\RRD\RrdDefinition;
 
 $options      = '-O qv';
-$oid          = 'nsExtendOutputFull.11.109.97.105.108.115.99.97.110.110.101.114';
+$oid          = '.1.3.6.1.4.1.8072.1.3.2.3.1.2.11.109.97.105.108.115.99.97.110.110.101.114';
 
 $mailscanner = snmp_get($device, $oid, $options);
 update_application($app, $mailscanner);
