@@ -9,11 +9,12 @@ if (!empty($agent_data['app']['memcached'])) {
 } else {
     $oid     = '.1.3.6.1.4.1.8072.1.3.2.3.1.2.9.109.101.109.99.97.99.104.101.100';
     $result  = snmp_get($device, $oid, '-Oqv');
+    $result  = trim($result, '"');
     $result  = unserialize(stripslashes(str_replace("<<<app-memcached>>>\n", '', $result)));
     $data    = reset($result);
 }
 
-update_application($app, $data);
+update_application($app, $data['pid']);
 echo ' memcached('.$app['app_instance'].')';
 
 $rrd_name = array('app', $name, $app_id);
