@@ -6,9 +6,8 @@ $name = 'php-fpm';
 $app_id = $app['app_id'];
 
 $options      = '-O qv';
-$mib          = 'NET-SNMP-EXTEND-MIB';
-$oid          = 'nsExtendOutputFull.8.112.104.112.102.112.109.115.112';
-$phpfpm = snmp_walk($device, $oid, $options, $mib);
+$oid          = '.1.3.6.1.4.1.8072.1.3.2.3.1.2.8.112.104.112.102.112.109.115.112';
+$phpfpm = snmp_walk($device, $oid, $options);
 update_application($app, $phpfpm);
 
 list($pool,$start_time,$start_since,$accepted_conn,$listen_queue,$max_listen_queue,$listen_queue_len,$idle_processes,
