@@ -25,6 +25,5 @@ $serial = str_replace('"', '', $serial);
 $sysDescr = $poll_device['sysDescr'];
 $sysDescr = explode(' ', $sysDescr);
 $sysDescr = $sysDescr[0];
-$hwrevision = snmp_get($device, 'rcChasHardwareRevision.0', '-Osqv', 'RAPID-CITY');
-$hardware = $sysDescr . " HW: $hwrevision";
+$hardware = $sysDescr;
 $hardware = str_replace('"', '', $hardware);
