@@ -26,3 +26,11 @@
 preg_match("/CMTS_V([0-9\.]+),/", $poll_device['sysDescr'], $match);
 
 $version = $match[1];
+$data = explode(".", $poll_device["sysObjectID"]);
+$id = end($data);
+if ($id == "1") {
+    $hardware = "C4";
+} else if ($id == "2") {
+    $hardware = "C4c";
+}
+unset($data);
