@@ -1,6 +1,10 @@
 <?php
 
-$jun_ver = snmp_get($device, '.1.3.6.1.2.1.25.6.3.1.2.2', '-Oqv', 'HOST-RESOURCES-MIB');
+$version = snmp_get($device, 'jnxVirtualChassisMemberSWVersion.0', '-Oqv', 'JUNIPER-VIRTUALCHASSIS-MIB');
+if (empty($version)) {
+    preg_match('/\[(.+)\]/', snmp_get($device, '.1.3.6.1.2.1.25.6.3.1.2.2', '-Oqv', 'HOST-RESOURCES-MIB'), $jun_ver);
+    $version = $jun_ver[1];
+}
 
 if (strpos($poll_device['sysDescr'], 'olive')) {
     $hardware = 'Olive';
@@ -11,6 +15,4 @@ if (strpos($poll_device['sysDescr'], 'olive')) {
     $serial   = snmp_get($device, '.1.3.6.1.4.1.2636.3.1.3.0', '-OQv', '+JUNIPER-MIB', 'junos');
 }
 
-list($version)  = explode(']', $jun_ver);
-list(,$version) = explode('[', $version);
 $features       = '';
