@@ -25,4 +25,4 @@
 
 $version = snmp_get($device, 'firmwareVersion.0', '-OQva', 'NETONIX-SWITCH-MIB', 'netonix');
 $version = str_replace('.n.........', '', $version); // version display bug in 1.3.9
-$hardware = $poll_device['sysDescr'];
+$hardware = str_replace('Netonix ', '', $poll_device['sysDescr']);
