@@ -11,9 +11,7 @@
  */
 
 d_echo('EdgeSwitch CPU usage:');
-if ($device['os'] == 'edgeswitch') {
-    //SNMPv2-SMI::enterprises.4413.1.1.1.1.4.9.0
-    $proc_usage = snmp_get($device, '.1.3.6.1.4.1.4413.1.1.1.1.4.9.0', '-Ovq');
-    preg_match('/([0-9]+.[0-9]+)/', $proc_usage, $usage);
-    $proc = $usage[0];
-}
+//SNMPv2-SMI::enterprises.4413.1.1.1.1.4.9.0
+$proc_usage = snmp_get($device, '.1.3.6.1.4.1.4413.1.1.1.1.4.9.0', '-Ovq');
+preg_match('/([0-9]+.[0-9]+)/', $proc_usage, $usage);
+$proc = $usage[0];
