@@ -26,3 +26,11 @@
 if (empty($config['email_from'])) {
     $config['email_from'] = '"' . $config['project_name'] . '" <' . $config['email_user'] . '@' . php_uname('n') . '>';
 }
+
+// Force rrdtool config; it's under packages control.
+$config['rrdtool'] = '/usr/local/bin/rrdtool';
+$config['rrdtool_version'] = 1.6;
+
+if ($config['secure_cookies']) {
+    ini_set('session.cookie_secure', 1);
+}
