@@ -82,6 +82,9 @@ db_port = int(config['db_port'])
 if config['db_host'][:5].lower() == 'unix:':
     db_server = config['db_host']
     db_port = 0
+elif config['db_socket']:
+    db_server = config['db_socket']
+    db_port = 0
 else:
     db_server = config['db_host']
 
